@@ -1,7 +1,7 @@
 #ifndef CACHE_SUPERBLOCK_H
 #define CACHE_SUPERBLOCK_H
 
-#include "persistent-data/endian_utils.h"
+#include "base/endian_utils.h"
 #include "persistent-data/data-structures/btree.h"
 
 #include <set>
@@ -30,6 +30,7 @@ namespace caching {
 		superblock_flags(uint32_t bits);
 
 		void set_flag(flag f);
+		void clear_flag(flag f);
 		bool get_flag(flag f) const;
 		uint32_t encode() const;
 		uint32_t get_unhandled_flags() const;
@@ -77,6 +78,10 @@ namespace caching {
 		uint32_t write_misses;
 	};
 
+	enum incompat_bits {
+		VARIABLE_HINT_SIZE_BIT = 0
+	};
+
 	//--------------------------------
 
 	namespace superblock_damage {
@@ -123,7 +128,7 @@ namespace caching {
 
 	//--------------------------------
 
-	persistent_data::block_manager<>::validator::ptr superblock_validator();
+	bcache::validator::ptr superblock_validator();
 
 	superblock read_superblock(persistent_data::block_manager<>::ptr bm,
 				   persistent_data::block_address location = SUPERBLOCK_LOCATION);
